#include <SPI.h>
#include <util.h>
#include <EthernetUdp2.h>
#include <Ethernet2.h>
#include <Twitter.h>
#include <EthernetServer.h>
#include <EthernetClient.h>
#include <Dns.h>
#include <Dhcp.h>
#include <Wire.h>


//TEMP
#define DS1631_A0 0
#define DS1631_A1 0
#define DS1631_A2 0
#define DS1631_CFG_R1     1  
#define DS1631_CFG_R0     1  
#define DS1631_CFG_POL    0  
#define DS1631_CFG_1SHOT  0
#define DS1631_ADDR (0x48 | DS1631_A2<<2 | DS1631_A1<<1 | DS1631_A0)
#define DS1631_CFG (DS1631_CFG_R1 << 3 \
                    | DS1631_CFG_R0 << 2 \
                    | DS1631_CFG_POL << 1 \
                    | DS1631_CFG_1SHOT)
#define DS1631_DONE_MASK 0x80;
//



byte mac[] = { 
  0x90, 0xA2, 0xDA, 0x10, 0xE2, 0xA4 };
  
IPAddress ip(192, 168, 1, 177);

EthernetServer server(8756);

String T[10];
String chaine = "";

//Pin connected to latch pin (ST_CP) of 74HC595
const int latchPin = 8;
//Pin connected to clock pin (SH_CP) of 74HC595
const int clockPin = 12;
////Pin connected to Data in (DS) of 74HC595
const int dataPin = 11;
// non OE
const int enablePin = 7;


void setup() {
  //set pins to output because they are addressed in the main loop
  pinMode(latchPin, OUTPUT);
  pinMode(dataPin, OUTPUT);  
  pinMode(clockPin, OUTPUT);
  pinMode(enablePin, OUTPUT);
  Serial.begin(9600);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for Leonardo only
  }
  Ethernet.begin(mac, ip);
  server.begin();
  Serial.print("server is at ");
  Serial.println(Ethernet.localIP());
  
  Serial.println("reset");
  

  //TEMP
   Wire.begin();
   Wire.beginTransmission(DS1631_ADDR);
   Wire.write(0x22); // Stop conversion
   Wire.endTransmission();
   
   Wire.beginTransmission(DS1631_ADDR);
   Wire.write(0xAC); // Access Configuration
   Wire.write(DS1631_CFG);
   Wire.endTransmission();

#if DS1631_CFG_1SHOT == 0
  // If continuous mode is set, start continuous conversion
  Wire.beginTransmission(DS1631_ADDR);
  Wire.write(0x51);
  Wire.endTransmission();
  delay(750); // delay to be sure that the first value is correct
#endif

  
}

void loop() {
  // listen for incoming clients
  EthernetClient client = server.available();
  if (client) {
    Serial.println("new client"); 
    //boolean currentLineIsBlank = true;
    
    while (client.connected()) {
      if (client.available()) {
        char c = client.read();
    
        // write to the shift register with the correct bit set high:
         if (c == '\n'){
            Serial.println("[" + chaine + "]");

             String reply = analys_msg(chaine);
             if (reply != ""){
              Serial.print("reply = ");
              Serial.println(reply.c_str());
              client.write(reply.c_str());
              client.write("\n");   
             }   
             chaine = "";
             continue;
          }
          else{
            chaine = chaine + c;
          }
    
        }
       }
     delay(1); 
     client.stop();
     Serial.println("client disonnected");
  }
}


String analys_msg(String msg){
    chaine.trim(); 

    if (chaine == "TEMP?"){
      float temp = 0.0;

        if (DS1631_CFG_1SHOT){ 
          Wire.beginTransmission(DS1631_ADDR);
          Wire.write(0x51);
          Wire.endTransmission();
          delay(750); // delay for 12 bits precision
          // Now we wait the end of the conversion
          boolean tempAvailable = false;
          while (!tempAvailable){
             // See if the conversion is finished
            // in the configuration DEC
            Wire.beginTransmission(DS1631_ADDR);
            Wire.write(0xAC);
            Wire.endTransmission();
            Wire.requestFrom(DS1631_ADDR,1);
            Wire.available();
            tempAvailable = Wire.read() & DS1631_DONE_MASK;
            delay(10);
            }
        }
        // read result
      Wire.beginTransmission(DS1631_ADDR);
      Wire.write(0xAA); // read last conversion
      Wire.endTransmission();
      Wire.requestFrom(DS1631_ADDR,2);
      Wire.available();
      int tempMS = (int) Wire.read();
      Wire.available();
      int tempLS = (int) Wire.read();
      Serial.print("tempMS:");
      Serial.println(tempMS);
      Serial.print("tempLS:");
      Serial.println(tempLS);

      tempLS >>= 4; // last 4 bits are always 0
      if (tempMS & 0x80){ // if the signed bit = 1
        tempMS -= 256;
      }
      // Float conversion
      temp = (float) (tempMS + tempLS*0.0625);
      String temp_str = String(temp);
      return temp_str;
    }

    if (chaine == "START"){
      digitalWrite(enablePin, LOW);
      return "";
    }

    if (chaine == "STOP") {
      digitalWrite(enablePin, HIGH);
      return "";
    }

   else{ 
    // byte bitsToSet = chaine.toInt();
    unsigned short int bitsToSet = chaine.toInt();
    Serial.println(bitsToSet, BIN);
       
     //registerWrite(bitToSet, HIGH);
     digitalWrite(latchPin, LOW);
            // shift the bits out:
      
     shiftOut(dataPin, clockPin, MSBFIRST, (bitsToSet >> 8 ));
     shiftOut(dataPin, clockPin, MSBFIRST, bitsToSet);
             // turn on the output so the LEDs can light up:
     digitalWrite(latchPin, HIGH);
     return "OK";
   }
   
}
 
      
